/**
 * $Id: FileHelper.java,v 1.7 2011/01/15 17:29:45 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 11.09.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.io;

import java.io.*;

/**
 * The Class FileHelper.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 11.09.2008
 * @version $Revision: 1.7 $
 */
public final class FileHelper {

    /** No need to instantiate it (utility class). */
    private FileHelper() {}

	/**
	 * Gets the tmpdir.
	 *
	 * @return the tmpdir
	 */
	public static File getTmpdir() {
		return new File(System.getProperty("java.io.tmpdir"));
	}

	/**
	 * Gets the tmpdir.
	 *
	 * @param file the file
	 *
	 * @return the tmpdir
	 */
	public static File getTmpdir(final File file) {
		return getTmpdir(file.toString());
	}

	/**
	 * Gets the tmpdir.
	 *
	 * @param filename the filename
	 *
	 * @return the tmpdir
	 */
	public static File getTmpdir(final String filename) {
		return new File(getTmpdir(), filename);
	}

	/**
     * Creates a directory in the temp directory.
     *
     * @return the directory
     * @throws IOException Signals that an I/O exception has occurred.
     */
    public static File createTmpdir() throws IOException {
        return createTmpdir("dir", "");
    }

	/**
	 * Creates a directory in the temp directory.
	 *
	 * @param prefix the prefix
	 * @param suffix the suffix
     * @return the directory
	 * @throws IOException Signals that an I/O exception has occurred.
	 */
	public static File createTmpdir(final String prefix, final String suffix) throws IOException {
	    File tmpdir = getTmpdir(prefix + System.currentTimeMillis() + suffix);
	    if (!tmpdir.mkdirs()) {
	        throw new IOException("can't create dir " + tmpdir);
	    }
	    return tmpdir;
	}

	/**
     * Gets the home dir.
     *
     * @return the home dir
     */
    public static File getHomeDir() {
        return new File(System.getProperty("user.home"));
    }

}
