/*
 * $Id: FileTester.java,v 1.2 2011/04/06 20:04:59 oboehm Exp $
 *
 * Copyright (c) 2011 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 06.04.2011 by oliver (ob@oasd.de)
 */

package patterntesting.runtime.junit;

import java.io.*;

import org.apache.commons.io.*;
import org.junit.Assert;

/**
 * @author oliver
 * @since 1.1 (06.04.2011)
 */
public class FileTester {
    
    /** Utility class - no need to instantiate it. */
    private FileTester() {}

    /**
     * Asserts that the content of two files are equal.
     * If they are not equals the first different line or byte will be shown.
     *
     * @param file1 the first file
     * @param file2 the second file
     * @throws AssertionError if the check fails
     */
    // TODO: should work also for directories
    public static void assertContentEquals(final File file1, final File file2)
            throws AssertionError {
        try {
            if (FileUtils.contentEquals(file1, file2)) {
                return;
            }
            Reader r1 = new FileReader(file1);
            Reader r2 = new FileReader(file2);
            try {
                IOTester.assertContentEquals(r1, r2);
            } finally {
                r1.close();
                r2.close();
            }
            throw new AssertionError(file1 + " and " + file2 + " differs");
        } catch (IOException ioe) {
            throwAssertionError("can't compare " + file1 + " with " + file2, ioe);
        }
    }
    
    /**
     * Two files are considered equals if the would point to the same file
     * location on the disk.
     *
     * @param file1 e.g. file "/a/b/c"
     * @param file2 e.g. file "/a/b/../b/c"
     */
    public static void assertEquals(final File file1, final File file2) {
        Assert.assertEquals(normalize(file1), normalize(file2));
    }
    
    private static File normalize(final File file) {
        String filename = null;
        try {
            filename = file.getCanonicalPath();
        } catch (IOException e) {
            filename = file.getAbsolutePath();
        }
        filename = FilenameUtils.normalize(filename);
        return new File(filename);
    }

    private static void throwAssertionError(String msg, Throwable t) throws AssertionError {
        AssertionError error = new AssertionError(msg);
        error.initCause(t);
        throw error;
    }

}

