/**
 * $Id: LogRecorder.java,v 1.5 2010/07/22 16:50:45 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 09.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.log;

import java.util.*;

import org.apache.commons.logging.Log;

import patterntesting.annotation.check.runtime.NullArgsAllowed;

/**
 * The Class LogRecorder which is able to record log messages.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 09.10.2008
 * @version $Revision: 1.5 $
 */
public final class LogRecorder implements Log {

	private final List<Object> objects = new ArrayList<Object>();
	private final List<Throwable> exceptions = new ArrayList<Throwable>();
	private int n = 0;

	/**
	 * Debug.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#debug(java.lang.Object)
	 */
	public void debug(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Debug.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#debug(java.lang.Object, java.lang.Throwable)
	 */
	public void debug(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Error.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#error(java.lang.Object)
	 */
	public void error(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Error.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#error(java.lang.Object, java.lang.Throwable)
	 */
	public void error(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Fatal.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#fatal(java.lang.Object)
	 */
	public void fatal(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Fatal.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#fatal(java.lang.Object, java.lang.Throwable)
	 */
	public void fatal(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Info.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#info(java.lang.Object)
	 */
	public void info(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Info.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#info(java.lang.Object, java.lang.Throwable)
	 */
	public void info(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Checks if is debug enabled.
	 *
	 * @return true, if is debug enabled
	 * @see org.apache.commons.logging.Log#isDebugEnabled()
	 */
	public boolean isDebugEnabled() {
		return false;
	}

	/**
	 * Checks if is error enabled.
	 *
	 * @return true, if is error enabled
	 * @see org.apache.commons.logging.Log#isErrorEnabled()
	 */
	public boolean isErrorEnabled() {
		return false;
	}

	/**
	 * Checks if is fatal enabled.
	 *
	 * @return true, if is fatal enabled
	 * @see org.apache.commons.logging.Log#isFatalEnabled()
	 */
	public boolean isFatalEnabled() {
		return false;
	}

	/**
	 * Checks if is info enabled.
	 *
	 * @return true, if is info enabled
	 * @see org.apache.commons.logging.Log#isInfoEnabled()
	 */
	public boolean isInfoEnabled() {
		return false;
	}

	/**
	 * Checks if is trace enabled.
	 *
	 * @return true, if is trace enabled
	 * @see org.apache.commons.logging.Log#isTraceEnabled()
	 */
	public boolean isTraceEnabled() {
		return false;
	}

	/**
	 * Checks if is warn enabled.
	 *
	 * @return true, if is warn enabled
	 * @see org.apache.commons.logging.Log#isWarnEnabled()
	 */
	public boolean isWarnEnabled() {
		return false;
	}

	/**
	 * Trace.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#trace(java.lang.Object)
	 */
	public void trace(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Trace.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#trace(java.lang.Object, java.lang.Throwable)
	 */
	public void trace(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Warn.
	 *
	 * @param arg0 the arg0
	 * @see org.apache.commons.logging.Log#warn(java.lang.Object)
	 */
	public void warn(final Object arg0) {
		this.record(arg0);
	}

	/**
	 * Warn.
	 *
	 * @param arg0 the arg0
	 * @param arg1 the arg1
	 * @see org.apache.commons.logging.Log#warn(java.lang.Object, java.lang.Throwable)
	 */
	public void warn(final Object arg0, final Throwable arg1) {
		this.record(arg0, arg1);
	}

	/**
	 * Record.
	 *
	 * @param obj the obj
	 */
	private void record(final Object obj) {
		this.record(obj, null);
	}

	/**
	 * Record.
	 *
	 * @param obj the obj
	 * @param t the t
	 */
	@NullArgsAllowed
	private synchronized void record(final Object obj, final Throwable t) {
		this.objects.add(obj);
		this.exceptions.add(t);
		this.n++;
	}

	/**
	 * Gets the text.
	 *
	 * @return the text
	 */
	public String getText() {
	    StringBuilder text = new StringBuilder();
		for (Object obj : this.objects) {
		    text.append(obj);
		}
		return text.toString().trim();
	}

	/**
	 * Gets the record.
	 *
	 * @return the record
	 */
	public String getRecord() {
		return getText();
	}

	/**
	 * Gets the number of records.
	 *
	 * @return the number of records
	 */
	public int getNumberOfRecords() {
		return n;
	}

    /**
     * To string.
     *
     * @return the string
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        String classname = this.getClass().getSimpleName();
        if (n == 1) {
            return classname + "(\"" + getRecord() + "\")";
        } else {
            return classname + " with " + n + " records";
        }
    }

}
